@@ -5,13 +5,15 @@
 #' @param formula Model formula accepting a single response (block) and predictors. See Details for more information.
 #' @param data The data set to analyse.
 #' @param contrasts Effect coding: "sum" (default = sum-coding), "weighted", "reference", "treatment".
+#' @param permute Number of permutations to perform (default = 1000).
+#' @param perm.type Type of permutation to perform, either "approximate" or "exact" (default = "approximate").
 # #' @param subset Expression for subsetting the data before modelling.
 # #' @param weights Optional object weights.
 # #' @param na.action How to handle NAs (no action implemented).
 # #' @param family Error distributions and link function for Generalized Linear Models.
 # #' @param permute Perform approximate permutation testing, default = FALSE (numeric or TRUE = 1000).
 # #' @param pca.in Compress response before ASCA (number of components).
-#' @param ... Additional arguments to \code{\link{asca_fit}}.
+#' @param ... Additional arguments to \code{\link{hdanova}}.
 #'
 #' @return An \code{asca} object containing loadings, scores, explained variances, etc. The object has
 #' associated plotting (\code{\link{asca_plots}}) and result (\code{\link{asca_results}}) functions.
@@ -36,7 +38,7 @@
 #' @importFrom lme4 lmer
 #' @importFrom car ellipse dataEllipse
 #' @seealso Main methods: \code{\link{asca}}, \code{\link{apca}}, \code{\link{limmpca}}, \code{\link{msca}}, \code{\link{pcanova}}, \code{\link{prc}} and \code{\link{permanova}}.
-#' Workhorse function underpinning most methods: \code{\link{asca_fit}}.
+#' Workhorse function underpinning most methods: \code{\link{hdanova}}.
 #' Extraction of results and plotting: \code{\link{asca_results}}, \code{\link{asca_plots}}, \code{\link{pcanova_results}} and \code{\link{pcanova_plots}}
 #' @examples
 #' # Load candies data
@@ -82,7 +84,8 @@
 #' summary(mod.perm)
 #'
 #' @export
-asca <- function(formula, data, contrasts = "contr.sum", ...){
+asca <- function(formula, data, contrasts = "contr.sum",
+                 permute = FALSE, perm.type=c("approximate","exact"),...){
   # formula, data, subset, weights, na.action, family, permute=FALSE,
   # unrestricted = FALSE,
   # add_error = FALSE, # TRUE => APCA/LiMM-PCA
@@ -91,7 +94,17 @@ asca <- function(formula, data, contrasts = "contr.sum", ...){
   # coding = c("sum","weighted","reference","treatment"),
   # SStype = "II",
   # REML = NULL
-  object <- asca_fit(formula=formula, data=data, contrasts = contrasts, ...)
+  object <- hdanova(formula=formula, data=data, contrasts = contrasts, ...)
+  if(!(is.logical(permute) && !permute)){
+    # Default to 1000 permutations             ------------- Flytt testing til ASCA og venner
+    if(is.logical(permute)){
+      permute <- 1000
+      if(interactive())
+        message("Defaulting to 1000 permutations\n")
+    }
+    object <- permutation(object, permute=permute, perm.type=perm.type)
+  }
+  object <- sca(object)
   object$call <- match.call()
   object
 }
